package com.ruoyi.basicData.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.basicData.domain.TCustomerContact;

import java.util.List;
import java.util.Map;


/**
 * 客户联系人Mapper接口
 *
 * @author ruoyi
 * @date 2020-12-11
 */
public interface TCustomerContactMapper extends BaseMapper<TCustomerContact> {
    /**
     * 查询客户联系人
     *
     * @param tId 客户联系人ID
     * @return 客户联系人
     */
    public TCustomerContact selectTCustomerContactById(Long tId);

    /**
     * 查询客户联系人列表
     *
     * @param tCustomerContact 客户联系人
     * @return 客户联系人集合
     */
    public List<TCustomerContact> selectTCustomerContactList(TCustomerContact tCustomerContact);

    /**
     * 新增客户联系人
     *
     * @param tCustomerContact 客户联系人
     * @return 结果
     */
    public int insertTCustomerContact(TCustomerContact tCustomerContact);

    /**
     * 修改客户联系人
     *
     * @param tCustomerContact 客户联系人
     * @return 结果
     */
    public int updateTCustomerContact(TCustomerContact tCustomerContact);

    /**
     * 删除客户联系人
     *
     * @param tId 客户联系人ID
     * @return 结果
     */
    public int deleteTCustomerContactById(Long tId);

    /**
     * 批量删除客户联系人
     *
     * @param tIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteTCustomerContactByIds(Long[] tIds);

    int deleteCustomerContactByCorps(Long fPid);

    /**
     *  查询手机号是否存在
     * @param ftel
     * @return
     */
    public int checkTelUnique(String ftel);

    /**
     *  查询客户名
     * @param ftel
     * @return
     */
    public Map<String, Object> getCustomerName(String ftel);
}
